aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/kicking.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/csapi/kicking.h')
-rw-r--r--lib/csapi/kicking.h59
1 files changed, 32 insertions, 27 deletions
diff --git a/lib/csapi/kicking.h b/lib/csapi/kicking.h
index 5968187e..6ac106e2 100644
--- a/lib/csapi/kicking.h
+++ b/lib/csapi/kicking.h
@@ -6,32 +6,37 @@
#include "jobs/basejob.h"
+namespace Quotient {
-namespace QMatrixClient
-{
- // Operations
+/*! \brief Kick a user from the room.
+ *
+ * Kick a user from the room.
+ *
+ * The caller must have the required power level in order to perform this
+ * operation.
+ *
+ * Kicking a user adjusts the target member's membership state to be `leave`
+ * with an optional `reason`. Like with other membership changes, a user can
+ * directly adjust the target member's state by making a request to
+ * `/rooms/<room id>/state/m.room.member/<user id>`.
+ */
+class QUOTIENT_API KickJob : public BaseJob {
+public:
+ /*! \brief Kick a user from the room.
+ *
+ * \param roomId
+ * The room identifier (not alias) from which the user should be kicked.
+ *
+ * \param userId
+ * The fully qualified user ID of the user being kicked.
+ *
+ * \param reason
+ * The reason the user has been kicked. This will be supplied as the
+ * `reason` on the target's updated
+ * [`m.room.member`](/client-server-api/#mroommember) event.
+ */
+ explicit KickJob(const QString& roomId, const QString& userId,
+ const QString& reason = {});
+};
- /// Kick a user from the room.
- ///
- /// Kick a user from the room.
- ///
- /// The caller must have the required power level in order to perform this operation.
- ///
- /// Kicking a user adjusts the target member's membership state to be ``leave`` with an
- /// optional ``reason``. Like with other membership changes, a user can directly adjust
- /// the target member's state by making a request to ``/rooms/<room id>/state/m.room.member/<user id>``.
- class KickJob : public BaseJob
- {
- public:
- /*! Kick a user from the room.
- * \param roomId
- * The room identifier (not alias) from which the user should be kicked.
- * \param userId
- * The fully qualified user ID of the user being kicked.
- * \param reason
- * The reason the user has been kicked. This will be supplied as the
- * ``reason`` on the target's updated `m.room.member`_ event.
- */
- explicit KickJob(const QString& roomId, const QString& userId, const QString& reason = {});
- };
-} // namespace QMatrixClient
+} // namespace Quotient